@@ -13,6 +13,7 @@ from .checkpointing import (
     read_function,
     read_mesh,
     read_meshtags,
+    read_timestamps,
     write_attributes,
     write_function,
     write_mesh,
@@ -43,4 +44,5 @@ __all__ = [
     "write_mesh_input_order",
     "write_attributes",
     "read_attributes",
+    "read_timestamps",
 ]
